SmallLruCache

Struct SmallLruCache 

pub struct SmallLruCache<K, V, const N: usize, I: IndexType = u8, S = HeaplessBTreeLruCache<K, V, N, I>>
where S: AnyLruCache<K, V>,
{ /* private fields */ }
A structure representing SmallLruCache.

This LRU cache limits its entries natively using a stack layout up to size N. Beyond N, operations will cause the cache to spill transparently into a heap allocated lru::LruCache.

Implementations

Source

impl<K, V, const N: usize, I, S> SmallLruCache<K, V, N, I, S>
where K: Hash + Eq + Ord + Clone, I: IndexType, S: AnyLruCache<K, V>,

pub fn len(&self) -> usize

Returns the number of key-value pairs currently in the cache.

pub fn is_empty(&self) -> bool

Returns true if the cache is empty.

pub fn capacity(&self) -> NonZeroUsize

Returns the maximum capacity of the cache.

pub fn get<Q>(&mut self, key: &Q) -> Option<&V>
where K: Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Returns a reference to the value corresponding to the key, moving it to the MRU position.

pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
where K: Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Returns a mutable reference to the value corresponding to the key, moving it to the MRU position.

pub fn peek<Q>(&self, key: &Q) -> Option<&V>
where K: Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Returns a reference to the value corresponding to the key without updating the LRU state.

pub fn put(&mut self, key: K, value: V) -> Option<V>

Pushes a key-value pair into the cache. If the key already exists, updates the value and returns it.

If the stack capacity N is exceeded during put, this will transparently allocate a lru::LruCache and spill all elements to the heap.

pub fn clear(&mut self)

Clears the cache, removing all key-value pairs.

pub fn is_on_stack(&self) -> bool

Returns true if this cache is currently allocated entirely on the stack.

pub fn contains<Q>(&self, key: &Q) -> bool
where K: Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Returns true if the cache contains a value for the specified key.

pub fn push(&mut self, key: K, value: V) -> Option<(K, V)>

Pushes a key-value pair into the cache. If the key already exists, updates the value. If pushing causes the capacity to be exceeded, returns the evicted LRU pair.

pub fn pop<Q>(&mut self, key: &Q) -> Option<V>
where K: Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Removes and returns the value corresponding to the key from the cache.

pub fn pop_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
where K: Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Removes and returns the key-value pair corresponding to the key from the cache.

pub fn pop_lru(&mut self) -> Option<(K, V)>

Removes and returns the Least Recently Used (LRU) key-value pair.

pub fn promote<Q>(&mut self, key: &Q)
where K: Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Explictly promotes the corresponding key to the Most Recently Used (MRU) position.

pub fn demote<Q>(&mut self, key: &Q)
where K: Borrow<Q>, Q: Hash + Eq + Ord + ?Sized,

Explicitly demotes the corresponding key to the Least Recently Used (LRU) position.

pub fn peek_lru(&self) -> Option<(&K, &V)>

Returns references to the Least Recently Used (LRU) key-value pair without removing it.

pub fn resize(&mut self, cap: NonZeroUsize)

Resizes the cache to a new maximum capacity. If the new capacity exceeds the stack limit N, it transparently spills to the heap.

pub fn get_or_insert<F>(&mut self, key: K, f: F) -> &V
where F: FnOnce() -> V,

Returns a reference to the value for the key, or inserts a new one.

pub fn get_or_insert_mut<F>(&mut self, key: K, f: F) -> &mut V
where F: FnOnce() -> V,

Returns a mutable reference to the value for the key, or inserts a new one.

pub fn iter(&self) -> Iter<'_, K, V, N, I, S>
where for<'a> S: LruIteratorSupport<'a, K, V>,

Returns an iterator over the elements.

pub fn iter_mut(&mut self) -> IterMut<'_, K, V, N, I, S>
where for<'a> S: LruIteratorSupport<'a, K, V>,

Returns an iterator over the elements.

Source

impl<K, V, const N: usize, I, S> SmallLruCache<K, V, N, I, S>
where K: Hash + Eq + Ord + Clone, I: IndexType, S: AnyLruCache<K, V> + Default,

pub fn new(cap: NonZeroUsize) -> Self

Automatically generated documentation for this item.