Module maps

Module maps 

Exposes maps collection module.

Modules

btree_map
Sorted map that lives on the stack and spills to the heap.
heapless_btree_map
Stack-allocated sorted map and its key-value entry type.
heapless_ordered_map
Stack-allocated insertion-order map.
map
Hash map that lives on the stack and spills to the heap.
ordered_map
Insertion-order-preserving map that lives on the stack and spills to the heap.