Module ordered_map

Module ordered_map 

Insertion-order-preserving map that lives on the stack and spills to the heap.

Provides SmallOrderedMap — backed by HeaplessOrderedMap on the stack and ordermap::OrderMap on the heap. Insertion order is maintained across both storage backends.

Re-exports AnyMap from map.rs as the common trait.

Re-exports

pub use crate::AnyMap;

Structs

SmallOrderedMap
An insertion-order-preserving map that lives on the stack for up to N entries, then spills to a heap-allocated ordermap::OrderMap.

Enums

SmallMapIntoIter
Types of SmallMapIntoIter.
SmallMapIter
Types of SmallMapIter.