Module bitvec

Module bitvec 

Bit vector that lives on the stack and spills to the heap.

Provides SmallBitVec — backed by HeaplessBitVec on the stack and bitvec::prelude::BitVec on the heap. AnyBitVec is the object-safe inspection trait implemented by both.

Structs

SmallBitVec
A bit vector that lives on the stack for N * 8 bits, then spills to a heap bitvec::BitVec.

Traits

AnyBitVec
A trait for uniform inspection of bit vectors.