AnyBitVec

Trait AnyBitVec 

pub trait AnyBitVec {
    // Required methods
    fn len(&self) -> usize;
    fn get(&self, index: usize) -> Option<bool>;

    // Provided method
    fn is_empty(&self) -> bool { ... }
}
A trait for uniform inspection of bit vectors.

Required Methods

fn len(&self) -> usize

Returns the number of bits in the bit vector.

fn get(&self, index: usize) -> Option<bool>

Returns the bit value at the given index, or None if out of bounds.

Provided Methods

fn is_empty(&self) -> bool

Returns true if the bit vector contains no bits.

Implementations on Foreign Types

Source

impl<O: BitOrder> AnyBitVec for BitVec<u8, O>

Source

fn len(&self) -> usize

Source

fn get(&self, index: usize) -> Option<bool>

Implementors

Source

impl<const N: usize, O: BitOrder> AnyBitVec for HeaplessBitVec<N, O>

Source

impl<const N: usize, O: BitOrder> AnyBitVec for SmallBitVec<N, O>