pub struct SmallLruCache<K, V, const N: usize, I: IndexType = u8, S = HeaplessBTreeLruCache<K, V, N, I>>where
S: AnyLruCache<K, V>,{ /* private fields */ }Expand description
A structure representing SmallLruCache.
This LRU cache limits its entries natively using a stack layout up to size N.
Beyond N, operations will cause the cache to spill transparently into a heap
allocated lru::LruCache.
Implementations
Sourceimpl<K, V, const N: usize, I, S> SmallLruCache<K, V, N, I, S>
impl<K, V, const N: usize, I, S> SmallLruCache<K, V, N, I, S>
Sourcepub fn capacity(&self) -> NonZeroUsize
pub fn capacity(&self) -> NonZeroUsize
Returns the maximum capacity of the cache.
Sourcepub fn get<Q>(&mut self, key: &Q) -> Option<&V>
pub fn get<Q>(&mut self, key: &Q) -> Option<&V>
Returns a reference to the value corresponding to the key, moving it to the MRU position.
Sourcepub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
pub fn get_mut<Q>(&mut self, key: &Q) -> Option<&mut V>
Returns a mutable reference to the value corresponding to the key, moving it to the MRU position.
Sourcepub fn peek<Q>(&self, key: &Q) -> Option<&V>
pub fn peek<Q>(&self, key: &Q) -> Option<&V>
Returns a reference to the value corresponding to the key without updating the LRU state.
Sourcepub fn put(&mut self, key: K, value: V) -> Option<V>
pub fn put(&mut self, key: K, value: V) -> Option<V>
Pushes a key-value pair into the cache. If the key already exists, updates the value and returns it.
If the stack capacity N is exceeded during put, this will transparently allocate a lru::LruCache
and spill all elements to the heap.
Sourcepub fn is_on_stack(&self) -> bool
pub fn is_on_stack(&self) -> bool
Returns true if this cache is currently allocated entirely on the stack.
Sourcepub fn contains<Q>(&self, key: &Q) -> bool
pub fn contains<Q>(&self, key: &Q) -> bool
Returns true if the cache contains a value for the specified key.
Sourcepub fn push(&mut self, key: K, value: V) -> Option<(K, V)>
pub fn push(&mut self, key: K, value: V) -> Option<(K, V)>
Pushes a key-value pair into the cache. If the key already exists, updates the value. If pushing causes the capacity to be exceeded, returns the evicted LRU pair.
Sourcepub fn pop<Q>(&mut self, key: &Q) -> Option<V>
pub fn pop<Q>(&mut self, key: &Q) -> Option<V>
Removes and returns the value corresponding to the key from the cache.
Sourcepub fn pop_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
pub fn pop_entry<Q>(&mut self, key: &Q) -> Option<(K, V)>
Removes and returns the key-value pair corresponding to the key from the cache.
Sourcepub fn pop_lru(&mut self) -> Option<(K, V)>
pub fn pop_lru(&mut self) -> Option<(K, V)>
Removes and returns the Least Recently Used (LRU) key-value pair.
Sourcepub fn promote<Q>(&mut self, key: &Q)
pub fn promote<Q>(&mut self, key: &Q)
Explictly promotes the corresponding key to the Most Recently Used (MRU) position.
Sourcepub fn demote<Q>(&mut self, key: &Q)
pub fn demote<Q>(&mut self, key: &Q)
Explicitly demotes the corresponding key to the Least Recently Used (LRU) position.
Sourcepub fn peek_lru(&self) -> Option<(&K, &V)>
pub fn peek_lru(&self) -> Option<(&K, &V)>
Returns references to the Least Recently Used (LRU) key-value pair without removing it.
Sourcepub fn resize(&mut self, cap: NonZeroUsize)
pub fn resize(&mut self, cap: NonZeroUsize)
Resizes the cache to a new maximum capacity.
If the new capacity exceeds the stack limit N, it transparently spills to the heap.
Sourcepub fn get_or_insert<F>(&mut self, key: K, f: F) -> &Vwhere
F: FnOnce() -> V,
pub fn get_or_insert<F>(&mut self, key: K, f: F) -> &Vwhere
F: FnOnce() -> V,
Returns a reference to the value for the key, or inserts a new one.
Sourcepub fn get_or_insert_mut<F>(&mut self, key: K, f: F) -> &mut Vwhere
F: FnOnce() -> V,
pub fn get_or_insert_mut<F>(&mut self, key: K, f: F) -> &mut Vwhere
F: FnOnce() -> V,
Returns a mutable reference to the value for the key, or inserts a new one.
Sourcepub fn iter(&self) -> Iter<'_, K, V, N, I, S> ⓘwhere
for<'a> S: LruIteratorSupport<'a, K, V>,
pub fn iter(&self) -> Iter<'_, K, V, N, I, S> ⓘwhere
for<'a> S: LruIteratorSupport<'a, K, V>,
Returns an iterator over the elements.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, K, V, N, I, S> ⓘwhere
for<'a> S: LruIteratorSupport<'a, K, V>,
pub fn iter_mut(&mut self) -> IterMut<'_, K, V, N, I, S> ⓘwhere
for<'a> S: LruIteratorSupport<'a, K, V>,
Returns an iterator over the elements.
Sourceimpl<K, V, const N: usize, I, S> SmallLruCache<K, V, N, I, S>
impl<K, V, const N: usize, I, S> SmallLruCache<K, V, N, I, S>
Sourcepub fn new(cap: NonZeroUsize) -> Self
pub fn new(cap: NonZeroUsize) -> Self
Automatically generated documentation for this item.