Insertion-order-preserving map that lives on the stack and spills to the heap.
Provides SmallOrderedMap — backed by HeaplessOrderedMap on the stack
and ordermap::OrderMap on the heap. Insertion order is maintained across
both storage backends.
Re-exports AnyMap from map.rs as the common trait.
Re-exports
pub use crate::AnyMap;
Structs
- Small
Ordered Map - An insertion-order-preserving map that lives on the stack for up to
Nentries, then spills to a heap-allocatedordermap::OrderMap.
Enums
- Small
MapInto Iter - Types of
SmallMapIntoIter. - Small
MapIter - Types of
SmallMapIter.