pub struct SmallSet<T, const N: usize> { /* private fields */ }Expand description
A set that lives on the stack for N items, then automatically spills to the heap.
Implementation Details
This is a wrapper around SmallMap<T, (), N>. Since () is a zero-sized type in Rust,
this wrapper has zero memory overhead compared to a raw set implementation.
- Stack State: Zero allocations. Extremely fast FNV hashing.
- Heap State: Standard
HashMapperformance. - Spill: Zero-allocation move. Keys are moved, not cloned.
Implementations
Sourceimpl<T, const N: usize> SmallSet<T, N>
impl<T, const N: usize> SmallSet<T, N>
Sourcepub fn is_on_stack(&self) -> bool
pub fn is_on_stack(&self) -> bool
Returns true if the set is currently storing data on the stack.
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clears the set, removing all values.
This keeps the allocated memory (if on heap) for reuse.
Sourcepub fn insert(&mut self, value: T) -> bool
pub fn insert(&mut self, value: T) -> bool
Adds a value to the set.
Returns true if the value was newly inserted.
Returns false if the value was already present.
If the stack capacity N is exceeded, this triggers a spill to the heap.
Sourcepub fn contains<Q>(&self, value: &Q) -> bool
pub fn contains<Q>(&self, value: &Q) -> bool
Returns true if the set contains a value.
This method is generic over Q to allow looking up String keys with &str.
Sourcepub fn remove<Q>(&mut self, value: &Q) -> bool
pub fn remove<Q>(&mut self, value: &Q) -> bool
Removes a value from the set. Returns true if the value was present.
Sourcepub fn retain<F>(&mut self, f: F)
pub fn retain<F>(&mut self, f: F)
Retains only the elements specified by the predicate.
In other words, remove all elements e such that f(&e) returns false.
This method operates in O(n) time.
Sourcepub fn iter(&self) -> SetRefIter<'_, T> ⓘ
pub fn iter(&self) -> SetRefIter<'_, T> ⓘ
Returns an iterator visiting all elements in arbitrary order.
Sourcepub fn difference<'a, S>(&'a self, other: &'a S) -> impl Iterator<Item = &'a T>where
S: AnySet<T>,
pub fn difference<'a, S>(&'a self, other: &'a S) -> impl Iterator<Item = &'a T>where
S: AnySet<T>,
Visits the values representing the difference, i.e., the values that are in self but not in other.
other can be any collection implementing AnySet (SmallSet, HashSet, BTreeSet).
Sourcepub fn intersection<'a, S>(
&'a self,
other: &'a S,
) -> impl Iterator<Item = &'a T>where
S: AnySet<T>,
pub fn intersection<'a, S>(
&'a self,
other: &'a S,
) -> impl Iterator<Item = &'a T>where
S: AnySet<T>,
Visits the values representing the intersection, i.e., the values that are both in self and other.
Sourcepub fn union<'a, I>(&'a self, other: I) -> impl Iterator<Item = &'a T>
pub fn union<'a, I>(&'a self, other: I) -> impl Iterator<Item = &'a T>
Visits the values representing the union, i.e., all the values in self or other, without duplicates.
other can be any iterator yielding &T.
Sourcepub fn is_disjoint<S>(&self, other: &S) -> boolwhere
S: AnySet<T>,
pub fn is_disjoint<S>(&self, other: &S) -> boolwhere
S: AnySet<T>,
Returns true if self has no elements in common with other.
Sourcepub fn is_subset<S>(&self, other: &S) -> boolwhere
S: AnySet<T>,
pub fn is_subset<S>(&self, other: &S) -> boolwhere
S: AnySet<T>,
Returns true if self is a subset of other.
other must be a Set (implement AnySet) to ensure O(1) lookups.
Sourcepub fn is_superset<'a, I>(&self, other: I) -> boolwhere
T: 'a,
I: IntoIterator<Item = &'a T>,
pub fn is_superset<'a, I>(&self, other: I) -> boolwhere
T: 'a,
I: IntoIterator<Item = &'a T>,
Returns true if self is a superset of other.
other can be any iterator. We must ensure T lives as long as the iterator 'a.
Sourcepub fn symmetric_difference<'a>(
&'a self,
other: &'a SmallSet<T, N>,
) -> impl Iterator<Item = &'a T>
pub fn symmetric_difference<'a>( &'a self, other: &'a SmallSet<T, N>, ) -> impl Iterator<Item = &'a T>
Visits the values representing the symmetric difference,
i.e., values that are in self or other but not in both.