Bit vector that lives on the stack and spills to the heap.
Provides SmallBitVec — backed by HeaplessBitVec on the stack and
bitvec::prelude::BitVec on the heap. AnyBitVec is the object-safe
inspection trait implemented by both.
Structs
- Small
BitVec - A bit vector that lives on the stack for
N * 8bits, then spills to a heapbitvec::BitVec.
Traits
- AnyBit
Vec - A trait for uniform inspection of bit vectors.